@@ -6,19 +6,29 @@
 #' @param use_combinations Logical, should the output also include columns representing
 #'    the combination / interaction of the categories (defaults to \code{FALSE}).
 #'
-#' @return A matrix representing the categorical variables in binary form ("dummy coding")
+#' @return A matrix encoding the categorical variable(s) in binary form. 
 #'
 #' @details
 #' 
-#' The conversion of categorical variable to binary variables is done via
-#' \code{\link[stats]{model.matrix}}. This function can be used to include 
-#' categorical variables as part of the optimization criterion in k-means / 
-#' k-plus anticlustering, rather than including them as hard constraints as 
-#' done in \code{\link{anticlustering}}. This can be useful when there are several
-#' categorical variables or when the group sizes are unequal (or both).
-#' See examples.
+#' The conversion of categorical variables to binary variables is done via
+#' \code{\link[stats]{model.matrix}}. Since version 0.8.9, each category
+#' of a categorical variable is coded by a separate variable. So this is not
+#' 'dummy' coding, which is often used to encode predictors in statistical 
+#' analysis. Dummy coding uses a reference category that has only zeros for 
+#' each variable, while all other categories consist of a 1 and otherwise zeros. 
+#' This implies that there is a different distance to the reference category 
+#' than among the other categories, which is unwarranted in anticlustering.
 #' 
-#' @importFrom stats as.formula
+#' This function can be used to include categorical variables as part of the 
+#' optimization criterion in anticlustering, rather than including them as hard constraints as done when using the 
+#' argument \code{categories} in \code{\link{anticlustering}} (or \code{\link{fast_anticlustering}}). 
+#' This way, categorical variables are treated as numeric variables, 
+#' which can be useful when there are several
+#' categorical variables or when the group sizes are unequal (or both).
+#' See examples. Please see the vignette 'Using categorical variables with anticlustering'
+#' for more information on this approach.
+#' 
+#' @importFrom stats as.formula model.matrix contrasts
 #'
 #'
 #' @author
@@ -30,13 +40,15 @@
 #' Maximizing Between-Group Similarity. British Journal of Mathematical and 
 #' Statistical Psychology, 77(1), 80--102. https://doi.org/10.1111/bmsp.12315
 #' 
-#' 
-#' @importFrom stats model.matrix
 #' @export
 #'
 #' @examples
 #' 
-#' # Use Schaper data set for example
+#' # How to encode a categorical variable with three levels:
+#' unique(iris$Species)
+#' categories_to_binary(iris$Species)[c(1, 51, 101), ]
+#' 
+#' # Use Schaper data set for anticlustering example
 #' data(schaper2019)
 #' features <- schaper2019[, 3:6]
 #' K <- 3
@@ -45,7 +57,7 @@
 #' # - Generate data input for k-means anticlustering -
 #' # We conduct k-plus anticlustering by first generating k-plus variables, 
 #' # and also include the categorical variable as "numeric" input for the 
-#' # k-means optimization (rather than as input for the argument `categories`)
+#' # k-means optimization (rather than as input for the argument \code{categories})
 #' 
 #' input_data <- cbind(
 #'   kplus_moment_variables(features, T = 2), 
@@ -71,5 +83,9 @@ categories_to_binary <- function(categories, use_combinations = FALSE) {
   categories <- as.data.frame(lapply(categories, as.factor))
   combine_by <- ifelse(use_combinations, " * ", " + ")
   formula_string <- paste("~", paste(colnames(categories), collapse = combine_by), collapse = "")
-  model.matrix(as.formula(formula_string), data = categories)[ ,-1, drop = FALSE]
+  model.matrix(
+    as.formula(formula_string), 
+    data = categories,
+    contrasts.arg = lapply(categories, contrasts, contrasts=FALSE) # this ensures that each level of the category has a binary variable
+  )[ ,-1, drop = FALSE]
 }
